# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKPDEDeformableRegistrationPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkLevelSetMotionRegistrationFilterPython
else:
    import _itkLevelSetMotionRegistrationFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.itkPDEDeformableRegistrationFilterPython
import itk.itkImagePython
import itk.itkImageRegionPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkDenseFiniteDifferenceImageFilterPython
import itk.itkFiniteDifferenceImageFilterPython
import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterBPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageToImageFilterAPython
import itk.itkFiniteDifferenceFunctionPython

def itkLevelSetMotionRegistrationFilterIF2IF2IVF22_New():
    return itkLevelSetMotionRegistrationFilterIF2IF2IVF22.New()

class itkLevelSetMotionRegistrationFilterIF2IF2IVF22(itk.itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22):
    r"""Proxy of C++ itkLevelSetMotionRegistrationFilterIF2IF2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLevelSetMotionRegistrationFilterIF2IF2IVF22_Pointer"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF2IF2IVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLevelSetMotionRegistrationFilterIF2IF2IVF22_Pointer"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF2IF2IVF22_Clone(self)

    def GetMetric(self):
        r"""GetMetric(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF2IF2IVF22_GetMetric(self)

    def SetAlpha(self, arg0):
        r"""
        SetAlpha(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF2IF2IVF22_SetAlpha(self, arg0)

    def GetAlpha(self):
        r"""GetAlpha(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF2IF2IVF22_GetAlpha(self)

    def SetIntensityDifferenceThreshold(self, arg0):
        r"""
        SetIntensityDifferenceThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF2IF2IVF22_SetIntensityDifferenceThreshold(self, arg0)

    def GetIntensityDifferenceThreshold(self):
        r"""GetIntensityDifferenceThreshold(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF2IF2IVF22_GetIntensityDifferenceThreshold(self)

    def SetGradientMagnitudeThreshold(self, arg0):
        r"""
        SetGradientMagnitudeThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF2IF2IVF22_SetGradientMagnitudeThreshold(self, arg0)

    def GetGradientMagnitudeThreshold(self):
        r"""GetGradientMagnitudeThreshold(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF2IF2IVF22_GetGradientMagnitudeThreshold(self)

    def SetGradientSmoothingStandardDeviations(self, sigma):
        r"""
        SetGradientSmoothingStandardDeviations(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF2IF2IVF22_SetGradientSmoothingStandardDeviations(self, sigma)

    def GetGradientSmoothingStandardDeviations(self):
        r"""GetGradientSmoothingStandardDeviations(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF2IF2IVF22_GetGradientSmoothingStandardDeviations(self)
    __swig_destroy__ = _itkLevelSetMotionRegistrationFilterPython.delete_itkLevelSetMotionRegistrationFilterIF2IF2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLevelSetMotionRegistrationFilterIF2IF2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF2IF2IVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLevelSetMotionRegistrationFilterIF2IF2IVF22

        Create a new object of the class itkLevelSetMotionRegistrationFilterIF2IF2IVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLevelSetMotionRegistrationFilterIF2IF2IVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLevelSetMotionRegistrationFilterIF2IF2IVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLevelSetMotionRegistrationFilterIF2IF2IVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLevelSetMotionRegistrationFilterIF2IF2IVF22 in _itkLevelSetMotionRegistrationFilterPython:
_itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF2IF2IVF22_swigregister(itkLevelSetMotionRegistrationFilterIF2IF2IVF22)

def itkLevelSetMotionRegistrationFilterIF3IF3IVF33_New():
    return itkLevelSetMotionRegistrationFilterIF3IF3IVF33.New()

class itkLevelSetMotionRegistrationFilterIF3IF3IVF33(itk.itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33):
    r"""Proxy of C++ itkLevelSetMotionRegistrationFilterIF3IF3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLevelSetMotionRegistrationFilterIF3IF3IVF33_Pointer"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF3IF3IVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLevelSetMotionRegistrationFilterIF3IF3IVF33_Pointer"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF3IF3IVF33_Clone(self)

    def GetMetric(self):
        r"""GetMetric(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF3IF3IVF33_GetMetric(self)

    def SetAlpha(self, arg0):
        r"""
        SetAlpha(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF3IF3IVF33_SetAlpha(self, arg0)

    def GetAlpha(self):
        r"""GetAlpha(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF3IF3IVF33_GetAlpha(self)

    def SetIntensityDifferenceThreshold(self, arg0):
        r"""
        SetIntensityDifferenceThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF3IF3IVF33_SetIntensityDifferenceThreshold(self, arg0)

    def GetIntensityDifferenceThreshold(self):
        r"""GetIntensityDifferenceThreshold(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF3IF3IVF33_GetIntensityDifferenceThreshold(self)

    def SetGradientMagnitudeThreshold(self, arg0):
        r"""
        SetGradientMagnitudeThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF3IF3IVF33_SetGradientMagnitudeThreshold(self, arg0)

    def GetGradientMagnitudeThreshold(self):
        r"""GetGradientMagnitudeThreshold(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF3IF3IVF33_GetGradientMagnitudeThreshold(self)

    def SetGradientSmoothingStandardDeviations(self, sigma):
        r"""
        SetGradientSmoothingStandardDeviations(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF3IF3IVF33_SetGradientSmoothingStandardDeviations(self, sigma)

    def GetGradientSmoothingStandardDeviations(self):
        r"""GetGradientSmoothingStandardDeviations(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF3IF3IVF33_GetGradientSmoothingStandardDeviations(self)
    __swig_destroy__ = _itkLevelSetMotionRegistrationFilterPython.delete_itkLevelSetMotionRegistrationFilterIF3IF3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLevelSetMotionRegistrationFilterIF3IF3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF3IF3IVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLevelSetMotionRegistrationFilterIF3IF3IVF33

        Create a new object of the class itkLevelSetMotionRegistrationFilterIF3IF3IVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLevelSetMotionRegistrationFilterIF3IF3IVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLevelSetMotionRegistrationFilterIF3IF3IVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLevelSetMotionRegistrationFilterIF3IF3IVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLevelSetMotionRegistrationFilterIF3IF3IVF33 in _itkLevelSetMotionRegistrationFilterPython:
_itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIF3IF3IVF33_swigregister(itkLevelSetMotionRegistrationFilterIF3IF3IVF33)

def itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_New():
    return itkLevelSetMotionRegistrationFilterISS2ISS2IVF22.New()

class itkLevelSetMotionRegistrationFilterISS2ISS2IVF22(itk.itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22):
    r"""Proxy of C++ itkLevelSetMotionRegistrationFilterISS2ISS2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_Pointer"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS2ISS2IVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_Pointer"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_Clone(self)

    def GetMetric(self):
        r"""GetMetric(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_GetMetric(self)

    def SetAlpha(self, arg0):
        r"""
        SetAlpha(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_SetAlpha(self, arg0)

    def GetAlpha(self):
        r"""GetAlpha(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_GetAlpha(self)

    def SetIntensityDifferenceThreshold(self, arg0):
        r"""
        SetIntensityDifferenceThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_SetIntensityDifferenceThreshold(self, arg0)

    def GetIntensityDifferenceThreshold(self):
        r"""GetIntensityDifferenceThreshold(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_GetIntensityDifferenceThreshold(self)

    def SetGradientMagnitudeThreshold(self, arg0):
        r"""
        SetGradientMagnitudeThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_SetGradientMagnitudeThreshold(self, arg0)

    def GetGradientMagnitudeThreshold(self):
        r"""GetGradientMagnitudeThreshold(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_GetGradientMagnitudeThreshold(self)

    def SetGradientSmoothingStandardDeviations(self, sigma):
        r"""
        SetGradientSmoothingStandardDeviations(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_SetGradientSmoothingStandardDeviations(self, sigma)

    def GetGradientSmoothingStandardDeviations(self):
        r"""GetGradientSmoothingStandardDeviations(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_GetGradientSmoothingStandardDeviations(self)
    __swig_destroy__ = _itkLevelSetMotionRegistrationFilterPython.delete_itkLevelSetMotionRegistrationFilterISS2ISS2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLevelSetMotionRegistrationFilterISS2ISS2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLevelSetMotionRegistrationFilterISS2ISS2IVF22

        Create a new object of the class itkLevelSetMotionRegistrationFilterISS2ISS2IVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLevelSetMotionRegistrationFilterISS2ISS2IVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLevelSetMotionRegistrationFilterISS2ISS2IVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLevelSetMotionRegistrationFilterISS2ISS2IVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLevelSetMotionRegistrationFilterISS2ISS2IVF22 in _itkLevelSetMotionRegistrationFilterPython:
_itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS2ISS2IVF22_swigregister(itkLevelSetMotionRegistrationFilterISS2ISS2IVF22)

def itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_New():
    return itkLevelSetMotionRegistrationFilterISS3ISS3IVF33.New()

class itkLevelSetMotionRegistrationFilterISS3ISS3IVF33(itk.itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33):
    r"""Proxy of C++ itkLevelSetMotionRegistrationFilterISS3ISS3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_Pointer"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS3ISS3IVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_Pointer"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_Clone(self)

    def GetMetric(self):
        r"""GetMetric(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_GetMetric(self)

    def SetAlpha(self, arg0):
        r"""
        SetAlpha(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_SetAlpha(self, arg0)

    def GetAlpha(self):
        r"""GetAlpha(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_GetAlpha(self)

    def SetIntensityDifferenceThreshold(self, arg0):
        r"""
        SetIntensityDifferenceThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_SetIntensityDifferenceThreshold(self, arg0)

    def GetIntensityDifferenceThreshold(self):
        r"""GetIntensityDifferenceThreshold(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_GetIntensityDifferenceThreshold(self)

    def SetGradientMagnitudeThreshold(self, arg0):
        r"""
        SetGradientMagnitudeThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_SetGradientMagnitudeThreshold(self, arg0)

    def GetGradientMagnitudeThreshold(self):
        r"""GetGradientMagnitudeThreshold(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_GetGradientMagnitudeThreshold(self)

    def SetGradientSmoothingStandardDeviations(self, sigma):
        r"""
        SetGradientSmoothingStandardDeviations(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_SetGradientSmoothingStandardDeviations(self, sigma)

    def GetGradientSmoothingStandardDeviations(self):
        r"""GetGradientSmoothingStandardDeviations(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_GetGradientSmoothingStandardDeviations(self)
    __swig_destroy__ = _itkLevelSetMotionRegistrationFilterPython.delete_itkLevelSetMotionRegistrationFilterISS3ISS3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLevelSetMotionRegistrationFilterISS3ISS3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLevelSetMotionRegistrationFilterISS3ISS3IVF33

        Create a new object of the class itkLevelSetMotionRegistrationFilterISS3ISS3IVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLevelSetMotionRegistrationFilterISS3ISS3IVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLevelSetMotionRegistrationFilterISS3ISS3IVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLevelSetMotionRegistrationFilterISS3ISS3IVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLevelSetMotionRegistrationFilterISS3ISS3IVF33 in _itkLevelSetMotionRegistrationFilterPython:
_itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterISS3ISS3IVF33_swigregister(itkLevelSetMotionRegistrationFilterISS3ISS3IVF33)

def itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_New():
    return itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22.New()

class itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22(itk.itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22):
    r"""Proxy of C++ itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_Pointer"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_Pointer"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_Clone(self)

    def GetMetric(self):
        r"""GetMetric(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_GetMetric(self)

    def SetAlpha(self, arg0):
        r"""
        SetAlpha(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_SetAlpha(self, arg0)

    def GetAlpha(self):
        r"""GetAlpha(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_GetAlpha(self)

    def SetIntensityDifferenceThreshold(self, arg0):
        r"""
        SetIntensityDifferenceThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_SetIntensityDifferenceThreshold(self, arg0)

    def GetIntensityDifferenceThreshold(self):
        r"""GetIntensityDifferenceThreshold(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_GetIntensityDifferenceThreshold(self)

    def SetGradientMagnitudeThreshold(self, arg0):
        r"""
        SetGradientMagnitudeThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_SetGradientMagnitudeThreshold(self, arg0)

    def GetGradientMagnitudeThreshold(self):
        r"""GetGradientMagnitudeThreshold(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_GetGradientMagnitudeThreshold(self)

    def SetGradientSmoothingStandardDeviations(self, sigma):
        r"""
        SetGradientSmoothingStandardDeviations(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_SetGradientSmoothingStandardDeviations(self, sigma)

    def GetGradientSmoothingStandardDeviations(self):
        r"""GetGradientSmoothingStandardDeviations(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_GetGradientSmoothingStandardDeviations(self)
    __swig_destroy__ = _itkLevelSetMotionRegistrationFilterPython.delete_itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22

        Create a new object of the class itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22 in _itkLevelSetMotionRegistrationFilterPython:
_itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22_swigregister(itkLevelSetMotionRegistrationFilterIUC2IUC2IVF22)

def itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_New():
    return itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33.New()

class itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33(itk.itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33):
    r"""Proxy of C++ itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_Pointer"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_Pointer"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_Clone(self)

    def GetMetric(self):
        r"""GetMetric(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_GetMetric(self)

    def SetAlpha(self, arg0):
        r"""
        SetAlpha(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_SetAlpha(self, arg0)

    def GetAlpha(self):
        r"""GetAlpha(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_GetAlpha(self)

    def SetIntensityDifferenceThreshold(self, arg0):
        r"""
        SetIntensityDifferenceThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_SetIntensityDifferenceThreshold(self, arg0)

    def GetIntensityDifferenceThreshold(self):
        r"""GetIntensityDifferenceThreshold(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_GetIntensityDifferenceThreshold(self)

    def SetGradientMagnitudeThreshold(self, arg0):
        r"""
        SetGradientMagnitudeThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_SetGradientMagnitudeThreshold(self, arg0)

    def GetGradientMagnitudeThreshold(self):
        r"""GetGradientMagnitudeThreshold(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_GetGradientMagnitudeThreshold(self)

    def SetGradientSmoothingStandardDeviations(self, sigma):
        r"""
        SetGradientSmoothingStandardDeviations(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_SetGradientSmoothingStandardDeviations(self, sigma)

    def GetGradientSmoothingStandardDeviations(self):
        r"""GetGradientSmoothingStandardDeviations(self) -> double"""
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_GetGradientSmoothingStandardDeviations(self)
    __swig_destroy__ = _itkLevelSetMotionRegistrationFilterPython.delete_itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33

        Create a new object of the class itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33 in _itkLevelSetMotionRegistrationFilterPython:
_itkLevelSetMotionRegistrationFilterPython.itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33_swigregister(itkLevelSetMotionRegistrationFilterIUC3IUC3IVF33)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def level_set_motion_registration_filter(*args: itkt.ImageLike,  alpha: float=..., intensity_difference_threshold: float=..., gradient_magnitude_threshold: float=..., gradient_smoothing_standard_deviations: float=..., fixed_image: itkt.Image=..., moving_image: itkt.Image=..., initial_displacement_field: itkt.Image=..., smooth_displacement_field: bool=..., standard_deviations: Union[float, Sequence[float]]=..., smooth_update_field: bool=..., update_field_standard_deviations: Union[float, Sequence[float]]=..., maximum_error: float=..., maximum_kernel_width: int=..., difference_function=..., number_of_iterations: int=..., use_image_spacing: bool=..., maximum_rms_error: float=..., rms_change: float=..., manual_reinitialization: bool=..., is_initialized: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for LevelSetMotionRegistrationFilter"""
    import itk

    kwarg_typehints = { 'alpha':alpha,'intensity_difference_threshold':intensity_difference_threshold,'gradient_magnitude_threshold':gradient_magnitude_threshold,'gradient_smoothing_standard_deviations':gradient_smoothing_standard_deviations,'fixed_image':fixed_image,'moving_image':moving_image,'initial_displacement_field':initial_displacement_field,'smooth_displacement_field':smooth_displacement_field,'standard_deviations':standard_deviations,'smooth_update_field':smooth_update_field,'update_field_standard_deviations':update_field_standard_deviations,'maximum_error':maximum_error,'maximum_kernel_width':maximum_kernel_width,'difference_function':difference_function,'number_of_iterations':number_of_iterations,'use_image_spacing':use_image_spacing,'maximum_rms_error':maximum_rms_error,'rms_change':rms_change,'manual_reinitialization':manual_reinitialization,'is_initialized':is_initialized }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.LevelSetMotionRegistrationFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def level_set_motion_registration_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKPDEDeformableRegistration.LevelSetMotionRegistrationFilter
    level_set_motion_registration_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    level_set_motion_registration_filter.__doc__ = filter_object.__doc__



